Installation — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# Installation

PyProcar is supported by Python 3.x. Please install the following dependencies prior to installing PyProcar.

> - matplotlib

> - numpy

> - scipy

> - seekpath

> - ase

> - scikit-image

> - pychemia

> - pyvista

> - trimesh

## Installing with pip

To install PyProcar with pip use the following command:

    pip install pyprocar

## Installing with conda

To install PyProcar with conda use the following command:

    conda install -c conda-forge pyprocar

## Cloning through GitHub

To install PyProcar by cloning from GitHub go to PyProcar Github:

    git clone https://github.com/romerogroup/pyprocar.git
    cd pyprocar
    pip install .

## After Installation

Once you are done with the installation you can import PyProcar within Python with the command:

    import pyprocar

The command-line version of PyProcar can be invoked in a terminal with:

    procar.py

Please note that the command-line version might not be up-to-date with the library version.